Package dev.cel.common.values
-
Interface Summary Interface Description CelValueProvider CelValueProvider is an interface for constructing new struct values. -
Class Summary Class Description BaseProtoCelValueConverter BaseProtoCelValueConvertercontains the common logic for converting between native Java and protobuf objects toCelValue.BaseProtoMessageValueProvider BaseProtoMessageValueProvideris a common parent toProtoMessageValueProviderandProtoMessageLiteValueProvider.CombinedCelValueProvider TheCombinedCelValueProvidertakes one or moreCelValueProviderinstances and attempts to create aCelValueinstance for a given struct type name by calling each value provider in the order that they are provided to the constructor.ProtoCelValueConverter ProtoCelValueConverterhandles bidirectional conversion between native Java and protobuf objects toCelValue.ProtoMessageValue ProtoMessageValue is a struct value with protobuf support.ProtoMessageValueProvider ProtoMessageValueProviderconstructs new instances of a protobuf message given its fully qualified name and its fields to populate.